Class: Crisphive::CustomerAddressRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/crisphive/models/customer_address_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CustomerAddressRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/crisphive/models/customer_address_request.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Crisphive::CustomerAddressRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Crisphive::CustomerAddressRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'formatted')
    self.formatted = attributes[:'formatted']
  end

  if attributes.key?(:'latitude')
    self.latitude = attributes[:'latitude']
  end

  if attributes.key?(:'line')
    self.line = attributes[:'line']
  end

  if attributes.key?(:'line2')
    self.line2 = attributes[:'line2']
  end

  if attributes.key?(:'longitude')
    self.longitude = attributes[:'longitude']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end
end

Instance Attribute Details

#cityObject

Returns the value of attribute city.



18
19
20
# File 'lib/crisphive/models/customer_address_request.rb', line 18

def city
  @city
end

#countryObject

Returns the value of attribute country.



20
21
22
# File 'lib/crisphive/models/customer_address_request.rb', line 20

def country
  @country
end

#formattedObject

Returns the value of attribute formatted.



22
23
24
# File 'lib/crisphive/models/customer_address_request.rb', line 22

def formatted
  @formatted
end

#latitudeObject

Returns the value of attribute latitude.



24
25
26
# File 'lib/crisphive/models/customer_address_request.rb', line 24

def latitude
  @latitude
end

#lineObject

Returns the value of attribute line.



26
27
28
# File 'lib/crisphive/models/customer_address_request.rb', line 26

def line
  @line
end

#line2Object

Returns the value of attribute line2.



28
29
30
# File 'lib/crisphive/models/customer_address_request.rb', line 28

def line2
  @line2
end

#longitudeObject

Returns the value of attribute longitude.



30
31
32
# File 'lib/crisphive/models/customer_address_request.rb', line 30

def longitude
  @longitude
end

#postal_codeObject

Returns the value of attribute postal_code.



32
33
34
# File 'lib/crisphive/models/customer_address_request.rb', line 32

def postal_code
  @postal_code
end

#stateObject

Returns the value of attribute state.



34
35
36
# File 'lib/crisphive/models/customer_address_request.rb', line 34

def state
  @state
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/crisphive/models/customer_address_request.rb', line 388

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Crisphive.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/crisphive/models/customer_address_request.rb', line 52

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/crisphive/models/customer_address_request.rb', line 37

def self.attribute_map
  {
    :'city' => :'city',
    :'country' => :'country',
    :'formatted' => :'formatted',
    :'latitude' => :'latitude',
    :'line' => :'line',
    :'line2' => :'line2',
    :'longitude' => :'longitude',
    :'postal_code' => :'postal_code',
    :'state' => :'state'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/crisphive/models/customer_address_request.rb', line 364

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/crisphive/models/customer_address_request.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/crisphive/models/customer_address_request.rb', line 57

def self.openapi_types
  {
    :'city' => :'String',
    :'country' => :'String',
    :'formatted' => :'String',
    :'latitude' => :'Float',
    :'line' => :'String',
    :'line2' => :'String',
    :'longitude' => :'Float',
    :'postal_code' => :'String',
    :'state' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/crisphive/models/customer_address_request.rb', line 335

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      city == o.city &&
      country == o.country &&
      formatted == o.formatted &&
      latitude == o.latitude &&
      line == o.line &&
      line2 == o.line2 &&
      longitude == o.longitude &&
      postal_code == o.postal_code &&
      state == o.state
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



459
460
461
462
463
464
465
466
467
468
469
470
471
# File 'lib/crisphive/models/customer_address_request.rb', line 459

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


351
352
353
# File 'lib/crisphive/models/customer_address_request.rb', line 351

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



357
358
359
# File 'lib/crisphive/models/customer_address_request.rb', line 357

def hash
  [city, country, formatted, latitude, line, line2, longitude, postal_code, state].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/crisphive/models/customer_address_request.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@city.nil? && @city.to_s.length > 100
    invalid_properties.push('invalid value for "city", the character length must be smaller than or equal to 100.')
  end

  if !@country.nil? && @country.to_s.length > 100
    invalid_properties.push('invalid value for "country", the character length must be smaller than or equal to 100.')
  end

  if !@formatted.nil? && @formatted.to_s.length > 500
    invalid_properties.push('invalid value for "formatted", the character length must be smaller than or equal to 500.')
  end

  if !@latitude.nil? && @latitude > 90
    invalid_properties.push('invalid value for "latitude", must be smaller than or equal to 90.')
  end

  if !@latitude.nil? && @latitude < -90
    invalid_properties.push('invalid value for "latitude", must be greater than or equal to -90.')
  end

  if !@line.nil? && @line.to_s.length > 255
    invalid_properties.push('invalid value for "line", the character length must be smaller than or equal to 255.')
  end

  if !@line2.nil? && @line2.to_s.length > 255
    invalid_properties.push('invalid value for "line2", the character length must be smaller than or equal to 255.')
  end

  if !@longitude.nil? && @longitude > 180
    invalid_properties.push('invalid value for "longitude", must be smaller than or equal to 180.')
  end

  if !@longitude.nil? && @longitude < -180
    invalid_properties.push('invalid value for "longitude", must be greater than or equal to -180.')
  end

  if !@postal_code.nil? && @postal_code.to_s.length > 32
    invalid_properties.push('invalid value for "postal_code", the character length must be smaller than or equal to 32.')
  end

  if !@state.nil? && @state.to_s.length > 100
    invalid_properties.push('invalid value for "state", the character length must be smaller than or equal to 100.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



435
436
437
# File 'lib/crisphive/models/customer_address_request.rb', line 435

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/crisphive/models/customer_address_request.rb', line 441

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



429
430
431
# File 'lib/crisphive/models/customer_address_request.rb', line 429

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/crisphive/models/customer_address_request.rb', line 183

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@city.nil? && @city.to_s.length > 100
  return false if !@country.nil? && @country.to_s.length > 100
  return false if !@formatted.nil? && @formatted.to_s.length > 500
  return false if !@latitude.nil? && @latitude > 90
  return false if !@latitude.nil? && @latitude < -90
  return false if !@line.nil? && @line.to_s.length > 255
  return false if !@line2.nil? && @line2.to_s.length > 255
  return false if !@longitude.nil? && @longitude > 180
  return false if !@longitude.nil? && @longitude < -180
  return false if !@postal_code.nil? && @postal_code.to_s.length > 32
  return false if !@state.nil? && @state.to_s.length > 100
  true
end