Class: Crisphive::JobRequestEmergencyPreviewRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/crisphive/models/job_request_emergency_preview_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ JobRequestEmergencyPreviewRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Crisphive::JobRequestEmergencyPreviewRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Crisphive::JobRequestEmergencyPreviewRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'displacement_mode')
    self.displacement_mode = attributes[:'displacement_mode']
  end

  if attributes.key?(:'emergency_job_id')
    self.emergency_job_id = attributes[:'emergency_job_id']
  else
    self.emergency_job_id = nil
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  else
    self.mode = nil
  end

  if attributes.key?(:'start_at')
    self.start_at = attributes[:'start_at']
  else
    self.start_at = nil
  end

  if attributes.key?(:'technician_id')
    self.technician_id = attributes[:'technician_id']
  else
    self.technician_id = nil
  end
end

Instance Attribute Details

#displacement_modeObject

Fate of displaced jobs: reschedule (default — pushed to later windows) or reassign (handed to another feasible technician at their ORIGINAL time; no-capacity jobs fall back to reschedule).



19
20
21
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 19

def displacement_mode
  @displacement_mode
end

#emergency_job_idObject

ID of the P0 job to insert.



22
23
24
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 22

def emergency_job_id
  @emergency_job_id
end

#modeObject

Cascade mode: overtime = displaced jobs stay same-day (tech works late); next_day = overflow rolls to the next working day.



25
26
27
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 25

def mode
  @mode
end

#start_atObject

Desired start — business-local naive datetime, no offset. Must be in the future.



28
29
30
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 28

def start_at
  @start_at
end

#technician_idObject

Target technician (must belong to the business).



31
32
33
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 31

def technician_id
  @technician_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 242

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Crisphive.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 67

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 56

def self.attribute_map
  {
    :'displacement_mode' => :'displacement_mode',
    :'emergency_job_id' => :'emergency_job_id',
    :'mode' => :'mode',
    :'start_at' => :'start_at',
    :'technician_id' => :'technician_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 218

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 72

def self.openapi_types
  {
    :'displacement_mode' => :'String',
    :'emergency_job_id' => :'String',
    :'mode' => :'String',
    :'start_at' => :'String',
    :'technician_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



193
194
195
196
197
198
199
200
201
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      displacement_mode == o.displacement_mode &&
      emergency_job_id == o.emergency_job_id &&
      mode == o.mode &&
      start_at == o.start_at &&
      technician_id == o.technician_id
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 313

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 211

def hash
  [displacement_mode, emergency_job_id, mode, start_at, technician_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 134

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @emergency_job_id.nil?
    invalid_properties.push('invalid value for "emergency_job_id", emergency_job_id cannot be nil.')
  end

  if @mode.nil?
    invalid_properties.push('invalid value for "mode", mode cannot be nil.')
  end

  if @start_at.nil?
    invalid_properties.push('invalid value for "start_at", start_at cannot be nil.')
  end

  if @technician_id.nil?
    invalid_properties.push('invalid value for "technician_id", technician_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



289
290
291
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 289

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 295

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



283
284
285
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 283

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/crisphive/models/job_request_emergency_preview_request.rb', line 158

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  displacement_mode_validator = EnumAttributeValidator.new('String', ["reschedule", "reassign"])
  return false unless displacement_mode_validator.valid?(@displacement_mode)
  return false if @emergency_job_id.nil?
  return false if @mode.nil?
  mode_validator = EnumAttributeValidator.new('String', ["overtime", "next_day"])
  return false unless mode_validator.valid?(@mode)
  return false if @start_at.nil?
  return false if @technician_id.nil?
  true
end