Class: Crisphive::BusinessSkillApi
- Inherits:
-
Object
- Object
- Crisphive::BusinessSkillApi
- Defined in:
- lib/crisphive/api/business_skill_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ BusinessSkillApi
constructor
A new instance of BusinessSkillApi.
-
#list_skill_categories(opts = {}) ⇒ ListSkillCategories200Response
List skill categories Returns paginated skill categories for the current business, ordered alphabetically.
-
#list_skill_categories_with_http_info(opts = {}) ⇒ Array<(ListSkillCategories200Response, Integer, Hash)>
List skill categories Returns paginated skill categories for the current business, ordered alphabetically.
-
#list_skills(opts = {}) ⇒ ListSkills200Response
List all skills Returns the flat list of all active skills for the current business across every category.
-
#list_skills_by_category(id, opts = {}) ⇒ ListSkillsByCategory200Response
List skills in a category Returns paginated skills belonging to the given category, ordered alphabetically.
-
#list_skills_by_category_with_http_info(id, opts = {}) ⇒ Array<(ListSkillsByCategory200Response, Integer, Hash)>
List skills in a category Returns paginated skills belonging to the given category, ordered alphabetically.
-
#list_skills_with_http_info(opts = {}) ⇒ Array<(ListSkills200Response, Integer, Hash)>
List all skills Returns the flat list of all active skills for the current business across every category.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BusinessSkillApi
Returns a new instance of BusinessSkillApi.
19 20 21 |
# File 'lib/crisphive/api/business_skill_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/crisphive/api/business_skill_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_skill_categories(opts = {}) ⇒ ListSkillCategories200Response
List skill categories Returns paginated skill categories for the current business, ordered alphabetically.
28 29 30 31 |
# File 'lib/crisphive/api/business_skill_api.rb', line 28 def list_skill_categories(opts = {}) data, _status_code, _headers = list_skill_categories_with_http_info(opts) data end |
#list_skill_categories_with_http_info(opts = {}) ⇒ Array<(ListSkillCategories200Response, Integer, Hash)>
List skill categories Returns paginated skill categories for the current business, ordered alphabetically.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/crisphive/api/business_skill_api.rb', line 39 def list_skill_categories_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BusinessSkillApi.list_skill_categories ...' end # resource path local_var_path = '/skill-categories' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListSkillCategories200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BusinessSkillApi.list_skill_categories", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BusinessSkillApi#list_skill_categories\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_skills(opts = {}) ⇒ ListSkills200Response
List all skills
Returns the flat list of all active skills for the current business across every category. Use this to discover the skill UUIDs accepted in skill_ids when creating a job request. (For a category-grouped view, use GET /skill-categories and GET /skill-categories/id/skills.)
89 90 91 92 |
# File 'lib/crisphive/api/business_skill_api.rb', line 89 def list_skills(opts = {}) data, _status_code, _headers = list_skills_with_http_info(opts) data end |
#list_skills_by_category(id, opts = {}) ⇒ ListSkillsByCategory200Response
List skills in a category
Returns paginated skills belonging to the given category, ordered alphabetically. The members field on each skill is the count of active technicians currently assigned to it.
149 150 151 152 |
# File 'lib/crisphive/api/business_skill_api.rb', line 149 def list_skills_by_category(id, opts = {}) data, _status_code, _headers = list_skills_by_category_with_http_info(id, opts) data end |
#list_skills_by_category_with_http_info(id, opts = {}) ⇒ Array<(ListSkillsByCategory200Response, Integer, Hash)>
List skills in a category Returns paginated skills belonging to the given category, ordered alphabetically. The `members` field on each skill is the count of active technicians currently assigned to it.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/crisphive/api/business_skill_api.rb', line 161 def list_skills_by_category_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BusinessSkillApi.list_skills_by_category ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling BusinessSkillApi.list_skills_by_category" end # resource path local_var_path = '/skill-categories/{id}/skills'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListSkillsByCategory200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BusinessSkillApi.list_skills_by_category", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BusinessSkillApi#list_skills_by_category\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_skills_with_http_info(opts = {}) ⇒ Array<(ListSkills200Response, Integer, Hash)>
List all skills Returns the flat list of all active skills for the current business across every category. Use this to discover the skill UUIDs accepted in `skill_ids` when creating a job request. (For a category-grouped view, use GET /skill-categories and GET /skill-categories/id/skills.)
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/crisphive/api/business_skill_api.rb', line 98 def list_skills_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BusinessSkillApi.list_skills ...' end # resource path local_var_path = '/skills' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListSkills200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"BusinessSkillApi.list_skills", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BusinessSkillApi#list_skills\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |