Class: Crisphive::CustomerApi
- Inherits:
-
Object
- Object
- Crisphive::CustomerApi
- Defined in:
- lib/crisphive/api/customer_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_customer(customer_create_request, opts = {}) ⇒ CreateCustomer200Response
Create a customer Creates a customer record — the client/account profile a job request (work order) is booked against; use it to import or sync customers from your own CRM, website lead form or intake flow.
-
#create_customer_with_http_info(customer_create_request, opts = {}) ⇒ Array<(CreateCustomer200Response, Integer, Hash)>
Create a customer Creates a customer record — the client/account profile a job request (work order) is booked against; use it to import or sync customers from your own CRM, website lead form or intake flow.
-
#delete_customer(id, opts = {}) ⇒ ResponseEnvelope
Delete a customer Soft-deletes a customer record, removing it from the active customer directory; existing bookings keep their customer snapshot.
-
#delete_customer_with_http_info(id, opts = {}) ⇒ Array<(ResponseEnvelope, Integer, Hash)>
Delete a customer Soft-deletes a customer record, removing it from the active customer directory; existing bookings keep their customer snapshot.
-
#get_customer(id, opts = {}) ⇒ GetCustomer200Response
Get a customer Returns the full customer record: profile, contact details, tier and lifetime spending summary — a 360° client view for support, upsell or CRM enrichment.
-
#get_customer_with_http_info(id, opts = {}) ⇒ Array<(GetCustomer200Response, Integer, Hash)>
Get a customer Returns the full customer record: profile, contact details, tier and lifetime spending summary — a 360° client view for support, upsell or CRM enrichment.
-
#initialize(api_client = ApiClient.default) ⇒ CustomerApi
constructor
A new instance of CustomerApi.
-
#list_customers(opts = {}) ⇒ ListCustomers200Response
List customers Returns a paginated, searchable directory of the business's customer records — the customer database (CRM) behind every booking and work order.
-
#list_customers_with_http_info(opts = {}) ⇒ Array<(ListCustomers200Response, Integer, Hash)>
List customers Returns a paginated, searchable directory of the business's customer records — the customer database (CRM) behind every booking and work order.
-
#update_customer(id, customer_update_request, opts = {}) ⇒ ResponseEnvelope
Update a customer Replaces mutable fields on a customer record — two-way CRM sync friendly (push changes from your system of record).
-
#update_customer_with_http_info(id, customer_update_request, opts = {}) ⇒ Array<(ResponseEnvelope, Integer, Hash)>
Update a customer Replaces mutable fields on a customer record — two-way CRM sync friendly (push changes from your system of record).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CustomerApi
Returns a new instance of CustomerApi.
19 20 21 |
# File 'lib/crisphive/api/customer_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/crisphive/api/customer_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_customer(customer_create_request, opts = {}) ⇒ CreateCustomer200Response
Create a customer
Creates a customer record — the client/account profile a job request (work order) is booked against; use it to import or sync customers from your own CRM, website lead form or intake flow. Address (street, city, postal_code, ...) and coordinates (latitude/longitude) live under the nested address object. service_area_id must be a valid service area UUID belonging to this business.
28 29 30 31 |
# File 'lib/crisphive/api/customer_api.rb', line 28 def create_customer(customer_create_request, opts = {}) data, _status_code, _headers = create_customer_with_http_info(customer_create_request, opts) data end |
#create_customer_with_http_info(customer_create_request, opts = {}) ⇒ Array<(CreateCustomer200Response, Integer, Hash)>
Create a customer Creates a customer record — the client/account profile a job request (work order) is booked against; use it to import or sync customers from your own CRM, website lead form or intake flow. Address (street, city, postal_code, ...) and coordinates (latitude/longitude) live under the nested `address` object. service_area_id must be a valid service area UUID belonging to this business.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/crisphive/api/customer_api.rb', line 39 def create_customer_with_http_info(customer_create_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomerApi.create_customer ...' end # verify the required parameter 'customer_create_request' is set if @api_client.config.client_side_validation && customer_create_request.nil? fail ArgumentError, "Missing the required parameter 'customer_create_request' when calling CustomerApi.create_customer" end # resource path local_var_path = '/customers' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(customer_create_request) # return_type return_type = opts[:debug_return_type] || 'CreateCustomer200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CustomerApi.create_customer", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomerApi#create_customer\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_customer(id, opts = {}) ⇒ ResponseEnvelope
Delete a customer Soft-deletes a customer record, removing it from the active customer directory; existing bookings keep their customer snapshot.
98 99 100 101 |
# File 'lib/crisphive/api/customer_api.rb', line 98 def delete_customer(id, opts = {}) data, _status_code, _headers = delete_customer_with_http_info(id, opts) data end |
#delete_customer_with_http_info(id, opts = {}) ⇒ Array<(ResponseEnvelope, Integer, Hash)>
Delete a customer Soft-deletes a customer record, removing it from the active customer directory; existing bookings keep their customer snapshot.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/crisphive/api/customer_api.rb', line 108 def delete_customer_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomerApi.delete_customer ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling CustomerApi.delete_customer" end # resource path local_var_path = '/customers/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ResponseEnvelope' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CustomerApi.delete_customer", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomerApi#delete_customer\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_customer(id, opts = {}) ⇒ GetCustomer200Response
Get a customer Returns the full customer record: profile, contact details, tier and lifetime spending summary — a 360° client view for support, upsell or CRM enrichment. contact.preferred_technician includes name. contact.service_area includes name. contact.address.latitude / contact.address.longitude are null if no coordinates saved.
161 162 163 164 |
# File 'lib/crisphive/api/customer_api.rb', line 161 def get_customer(id, opts = {}) data, _status_code, _headers = get_customer_with_http_info(id, opts) data end |
#get_customer_with_http_info(id, opts = {}) ⇒ Array<(GetCustomer200Response, Integer, Hash)>
Get a customer Returns the full customer record: profile, contact details, tier and lifetime spending summary — a 360° client view for support, upsell or CRM enrichment. contact.preferred_technician includes name. contact.service_area includes name. contact.address.latitude / contact.address.longitude are null if no coordinates saved.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/crisphive/api/customer_api.rb', line 171 def get_customer_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomerApi.get_customer ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling CustomerApi.get_customer" end # resource path local_var_path = '/customers/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetCustomer200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CustomerApi.get_customer", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomerApi#get_customer\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_customers(opts = {}) ⇒ ListCustomers200Response
List customers
Returns a paginated, searchable directory of the business's customer records — the customer database (CRM) behind every booking and work order. Supports the since/next_since cursor for incremental sync into an external CRM, ERP or marketing tool.
231 232 233 234 |
# File 'lib/crisphive/api/customer_api.rb', line 231 def list_customers(opts = {}) data, _status_code, _headers = list_customers_with_http_info(opts) data end |
#list_customers_with_http_info(opts = {}) ⇒ Array<(ListCustomers200Response, Integer, Hash)>
List customers Returns a paginated, searchable directory of the business's customer records — the customer database (CRM) behind every booking and work order. Supports the `since`/`next_since` cursor for incremental sync into an external CRM, ERP or marketing tool.
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/crisphive/api/customer_api.rb', line 248 def list_customers_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomerApi.list_customers ...' end # resource path local_var_path = '/customers' # query parameters query_params = opts[:query_params] || {} query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'tier'] = @api_client.build_collection_param(opts[:'tier'], :multi) if !opts[:'tier'].nil? query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? query_params[:'preferred_technician_id'] = opts[:'preferred_technician_id'] if !opts[:'preferred_technician_id'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'since'] = opts[:'since'] if !opts[:'since'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListCustomers200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CustomerApi.list_customers", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomerApi#list_customers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_customer(id, customer_update_request, opts = {}) ⇒ ResponseEnvelope
Update a customer
Replaces mutable fields on a customer record — two-way CRM sync friendly (push changes from your system of record). Pass service_area_id="" to clear the service area. Address fields (including latitude/longitude) live under the nested address object.
306 307 308 309 |
# File 'lib/crisphive/api/customer_api.rb', line 306 def update_customer(id, customer_update_request, opts = {}) data, _status_code, _headers = update_customer_with_http_info(id, customer_update_request, opts) data end |
#update_customer_with_http_info(id, customer_update_request, opts = {}) ⇒ Array<(ResponseEnvelope, Integer, Hash)>
Update a customer Replaces mutable fields on a customer record — two-way CRM sync friendly (push changes from your system of record). Pass service_area_id="" to clear the service area. Address fields (including latitude/longitude) live under the nested `address` object.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/crisphive/api/customer_api.rb', line 317 def update_customer_with_http_info(id, customer_update_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomerApi.update_customer ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling CustomerApi.update_customer" end # verify the required parameter 'customer_update_request' is set if @api_client.config.client_side_validation && customer_update_request.nil? fail ArgumentError, "Missing the required parameter 'customer_update_request' when calling CustomerApi.update_customer" end # resource path local_var_path = '/customers/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(customer_update_request) # return_type return_type = opts[:debug_return_type] || 'ResponseEnvelope' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"CustomerApi.update_customer", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomerApi#update_customer\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |