Class: Crisphive::JobTypesApi
- Inherits:
-
Object
- Object
- Crisphive::JobTypesApi
- Defined in:
- lib/crisphive/api/job_types_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_job_type(id, opts = {}) ⇒ GetJobType200Response
Get a job type Returns one entry of the business's service catalog (job/work-order type) with its localized display name — e.g.
-
#get_job_type_with_http_info(id, opts = {}) ⇒ Array<(GetJobType200Response, Integer, Hash)>
Get a job type Returns one entry of the business's service catalog (job/work-order type) with its localized display name — e.g.
-
#initialize(api_client = ApiClient.default) ⇒ JobTypesApi
constructor
A new instance of JobTypesApi.
-
#list_job_types(opts = {}) ⇒ ListJobTypes200Response
List job types Returns the business's service catalog — the job/work-order types it offers (e.g. installation, repair, maintenance, inspection for trades like HVAC, plumbing, electrical, cleaning).
-
#list_job_types_with_http_info(opts = {}) ⇒ Array<(ListJobTypes200Response, Integer, Hash)>
List job types Returns the business's service catalog — the job/work-order types it offers (e.g. installation, repair, maintenance, inspection for trades like HVAC, plumbing, electrical, cleaning).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ JobTypesApi
Returns a new instance of JobTypesApi.
19 20 21 |
# File 'lib/crisphive/api/job_types_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/crisphive/api/job_types_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_job_type(id, opts = {}) ⇒ GetJobType200Response
Get a job type Returns one entry of the business's service catalog (job/work-order type) with its localized display name — e.g. an HVAC tune-up, drain cleaning or electrical inspection offering.
27 28 29 30 |
# File 'lib/crisphive/api/job_types_api.rb', line 27 def get_job_type(id, opts = {}) data, _status_code, _headers = get_job_type_with_http_info(id, opts) data end |
#get_job_type_with_http_info(id, opts = {}) ⇒ Array<(GetJobType200Response, Integer, Hash)>
Get a job type Returns one entry of the business's service catalog (job/work-order type) with its localized display name — e.g. an HVAC tune-up, drain cleaning or electrical inspection offering.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/crisphive/api/job_types_api.rb', line 37 def get_job_type_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: JobTypesApi.get_job_type ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling JobTypesApi.get_job_type" end # resource path local_var_path = '/job-types/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetJobType200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"JobTypesApi.get_job_type", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: JobTypesApi#get_job_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_job_types(opts = {}) ⇒ ListJobTypes200Response
List job types
Returns the business's service catalog — the job/work-order types it offers (e.g. installation, repair, maintenance, inspection for trades like HVAC, plumbing, electrical, cleaning). Use it to discover the job_type_id accepted when booking a job request, or to render a services menu on your own site.
90 91 92 93 |
# File 'lib/crisphive/api/job_types_api.rb', line 90 def list_job_types(opts = {}) data, _status_code, _headers = list_job_types_with_http_info(opts) data end |
#list_job_types_with_http_info(opts = {}) ⇒ Array<(ListJobTypes200Response, Integer, Hash)>
List job types Returns the business's service catalog — the job/work-order types it offers (e.g. installation, repair, maintenance, inspection for trades like HVAC, plumbing, electrical, cleaning). Use it to discover the `job_type_id` accepted when booking a job request, or to render a services menu on your own site.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/crisphive/api/job_types_api.rb', line 100 def list_job_types_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: JobTypesApi.list_job_types ...' end # resource path local_var_path = '/job-types' # query parameters query_params = opts[:query_params] || {} query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListJobTypes200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"JobTypesApi.list_job_types", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: JobTypesApi#list_job_types\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |