Class: Crisphive::ServiceAreaApi
- Inherits:
-
Object
- Object
- Crisphive::ServiceAreaApi
- Defined in:
- lib/crisphive/api/service_area_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_service_area(id, opts = {}) ⇒ GetServiceArea200Response
Get a service area Returns details of a specific service area.
-
#get_service_area_with_http_info(id, opts = {}) ⇒ Array<(GetServiceArea200Response, Integer, Hash)>
Get a service area Returns details of a specific service area.
-
#initialize(api_client = ApiClient.default) ⇒ ServiceAreaApi
constructor
A new instance of ServiceAreaApi.
-
#list_service_areas(opts = {}) ⇒ ListServiceAreas200Response
List service areas Returns a paginated list of service areas for the business.
-
#list_service_areas_with_http_info(opts = {}) ⇒ Array<(ListServiceAreas200Response, Integer, Hash)>
List service areas Returns a paginated list of service areas for the business.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ServiceAreaApi
Returns a new instance of ServiceAreaApi.
19 20 21 |
# File 'lib/crisphive/api/service_area_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/crisphive/api/service_area_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_service_area(id, opts = {}) ⇒ GetServiceArea200Response
Get a service area Returns details of a specific service area
27 28 29 30 |
# File 'lib/crisphive/api/service_area_api.rb', line 27 def get_service_area(id, opts = {}) data, _status_code, _headers = get_service_area_with_http_info(id, opts) data end |
#get_service_area_with_http_info(id, opts = {}) ⇒ Array<(GetServiceArea200Response, Integer, Hash)>
Get a service area Returns details of a specific service area
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/crisphive/api/service_area_api.rb', line 37 def get_service_area_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServiceAreaApi.get_service_area ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ServiceAreaApi.get_service_area" end # resource path local_var_path = '/service-areas/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetServiceArea200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ServiceAreaApi.get_service_area", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServiceAreaApi#get_service_area\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_service_areas(opts = {}) ⇒ ListServiceAreas200Response
List service areas Returns a paginated list of service areas for the business
91 92 93 94 |
# File 'lib/crisphive/api/service_area_api.rb', line 91 def list_service_areas(opts = {}) data, _status_code, _headers = list_service_areas_with_http_info(opts) data end |
#list_service_areas_with_http_info(opts = {}) ⇒ Array<(ListServiceAreas200Response, Integer, Hash)>
List service areas Returns a paginated list of service areas for the business
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/crisphive/api/service_area_api.rb', line 102 def list_service_areas_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServiceAreaApi.list_service_areas ...' end # resource path local_var_path = '/service-areas' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListServiceAreas200Response' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKeyAuth'] = opts.merge( :operation => :"ServiceAreaApi.list_service_areas", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServiceAreaApi#list_service_areas\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |