Class: Crisphive::TechnicianApi

Inherits:
Object
  • Object
show all
Defined in:
lib/crisphive/api/technician_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ TechnicianApi

Returns a new instance of TechnicianApi.



19
20
21
# File 'lib/crisphive/api/technician_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/crisphive/api/technician_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_technician(id, opts = {}) ⇒ GetTechnician200Response

Get a technician Returns details for a specific technician

Parameters:

  • id (String)

    Technician ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/crisphive/api/technician_api.rb', line 27

def get_technician(id, opts = {})
  data, _status_code, _headers = get_technician_with_http_info(id, opts)
  data
end

#get_technician_with_http_info(id, opts = {}) ⇒ Array<(GetTechnician200Response, Integer, Hash)>

Get a technician Returns details for a specific technician

Parameters:

  • id (String)

    Technician ID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetTechnician200Response, Integer, Hash)>)

    GetTechnician200Response data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/crisphive/api/technician_api.rb', line 37

def get_technician_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TechnicianApi.get_technician ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling TechnicianApi.get_technician"
  end
  # resource path
  local_var_path = '/technicians/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetTechnician200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"TechnicianApi.get_technician",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TechnicianApi#get_technician\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_technicians(opts = {}) ⇒ ListTechnicians200Response

List technicians Returns a paginated list of technicians for the current business

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Page number (default 1)

  • :limit (Integer)

    Items per page (default 15, max 1000)

  • :status (String)

    Filter by status (active, onboarding, deactive)

  • :assignment_tier (String)

    Filter by assignment tier (lead, buddy, float)

  • :keyword (String)

    Search by full name, email, phone, or address

  • :sort (String)

    Sort: created_at_desc|created_at_asc|name_asc|name_desc (default: created_at_desc)

  • :since (String)

    RFC3339 cursor for short-polling; echo back next_since from prior response

Returns:



96
97
98
99
# File 'lib/crisphive/api/technician_api.rb', line 96

def list_technicians(opts = {})
  data, _status_code, _headers = list_technicians_with_http_info(opts)
  data
end

#list_technicians_with_http_info(opts = {}) ⇒ Array<(ListTechnicians200Response, Integer, Hash)>

List technicians Returns a paginated list of technicians for the current business

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Page number (default 1)

  • :limit (Integer)

    Items per page (default 15, max 1000)

  • :status (String)

    Filter by status (active, onboarding, deactive)

  • :assignment_tier (String)

    Filter by assignment tier (lead, buddy, float)

  • :keyword (String)

    Search by full name, email, phone, or address

  • :sort (String)

    Sort: created_at_desc|created_at_asc|name_asc|name_desc (default: created_at_desc)

  • :since (String)

    RFC3339 cursor for short-polling; echo back next_since from prior response

Returns:

  • (Array<(ListTechnicians200Response, Integer, Hash)>)

    ListTechnicians200Response data, response status code and response headers



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/crisphive/api/technician_api.rb', line 112

def list_technicians_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TechnicianApi.list_technicians ...'
  end
  # resource path
  local_var_path = '/technicians'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil?
  query_params[:'assignment_tier'] = opts[:'assignment_tier'] if !opts[:'assignment_tier'].nil?
  query_params[:'keyword'] = opts[:'keyword'] if !opts[:'keyword'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'since'] = opts[:'since'] if !opts[:'since'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListTechnicians200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKeyAuth']

  new_options = opts.merge(
    :operation => :"TechnicianApi.list_technicians",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TechnicianApi#list_technicians\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end